@@ -1,42 +1,17 @@
-package Net::MirrorDir;
-
-use 5.009002;
-use strict;
-use warnings;
-use Net::FTP;
-use vars '$AUTOLOAD';
-
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Net::MirrorDir ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '0.01';
-
-
-# Preloaded methods go here.
+#!/usr/local/bin/perl5.9.2 -w
+#*** MirrorDir.pm ***#
+# Copyright (C) 2006 Torsten Knorr
+# create-soft@tiscali.de
+# All rights reserved!
 #-------------------------------------------------
- my (
- 	$read_local_dir,
- 	$read_remote_dir,
- 	$ftp,
- 	);
+ package Net::MirrorDir;
+#-------------------------------------------------
+ use strict;
+ use warnings;
+ use Net::FTP;
+ use vars '$AUTOLOAD';
+#-------------------------------------------------
+ our $VERSION = '0.02';
 #-------------------------------------------------
  sub new
  	{
@@ -89,21 +64,23 @@ our $VERSION = '0.01';
 #-------------------------------------------------
  sub ReadLocalDir
  	{ 
- 	my ($self) = @_;
- 	my %local_files = ();
- 	my %local_dirs = ();
- 	$read_local_dir = sub
+ 	my ($self, $path) = @_;
+ 	delete($self->{_localfiles}{$_}) for(keys(%{$self->{_localfiles}}));
+ 	delete($self->{_localdirs}{$_}) for(keys(%{$self->{_localdirs}}));
+ 	$self->{_readlocaldir} = sub
  		{
- 		my $path = shift;
- 		if(-f $path)
+ 		my ($self, $p) = @_;
+ 		if(-f $p)
  			{
- 			$local_files{$path} = 1;
- 			return;
+ 			$self->{_localfiles}{$p} = 1;
+ 			return $self->{_localfiles}, $self->{_localdirs};
  			}
- 		if(-d $path)
+ 		if(-d $p)
  			{
- 			$local_dirs{$path} = 1;
- 			opendir(PATH, $path) or  die("cannot opendir $path : $!\n");
+ 			$self->{_localdirs}{$p} = 1;
+ 			opendir(PATH, $p) or
+ 				die("error in opendir $p : 
+ 				at Net::MirrorDir::ReadLocalDir() : $!\n");
  			my @files = readdir(PATH);
  			closedir(PATH);
  			FILE: for my $file (@files)
@@ -113,43 +90,40 @@ our $VERSION = '0.01';
  					{
  					next FILE if($file =~ m/$_/);
  					}
- 				$read_local_dir->("$path/$file");
+ 				$self->{_readlocaldir}->($self, "$p/$file");
  				}
- 			return;
+ 			return $self->{_localfiles}, $self->{_localdirs};
  			}
- 		warn("$path is neither a file nor a directory\n");
+ 		warn("$p is neither a file nor a directory\n");
  		};
- 	$read_local_dir->($self->{_localdir});
- 	return(\%local_files, \%local_dirs);
+ 	return $self->{_readlocaldir}->($self, ($path or $self->{_localdir}));
  	}
 #-------------------------------------------------
  sub ReadRemoteDir
  	{
- 	my ($self) = @_;
- 	my %remote_files = ();
- 	my %remote_dirs = ();
+ 	my ($self, $path) = @_;
  	return if(!(defined($self->{_connection})));
- 	$ftp = $self->{_connection};
- 	$read_remote_dir = sub 
+ 	delete($self->{_remotefiles}{$_}) for(keys(%{$self->{_remotefiles}}));
+ 	delete($self->{_remotedirs}{$_}) for(keys(%{$self->{_remotedirs}}));
+ 	$self->{_readremotedir} = sub 
  		{
- 		my $path = shift;
- 		if(defined($ftp->size($path)))
+ 		my ($self, $p) = @_;
+ 		if(defined($self->{_connection}->size($p)))
  			{
- 			$remote_files{$path} = 1;
- 			return;
+ 			$self->{_remotefiles}{$p} = 1;
+ 			return $self->{_remotefiles}, $self->{_remotedirs};
  			}
- 		if($ftp->cwd($path))
+ 		if($self->{_connection}->cwd($p))
  			{
- 			$ftp->cwd();
- 			$remote_dirs{$path} = 1;
- 			my @files = $ftp->ls($path);
- 			$read_remote_dir->("$path/$_") for(@files);
- 			return;
+ 			$self->{_connection}->cwd();
+ 			$self->{_remotedirs}{$p} = 1;
+ 			my @files = $self->{_connection}->ls($p);
+ 			$self->{_readremotedir}->($self, "$p/$_") for(@files);
+ 			return $self->{_remotefiles}, $self->{_remotedirs};
  			}
- 		warn("$path is neither a file nor a directory\n");
+ 		warn("$p is neither a file nor a directory\n");
  		};
- 	$read_remote_dir->($self->{_remotedir});
- 	return(\%remote_files, \%remote_dirs);
+ 	return $self->{_readremotedir}->($self, ($path or $self->{_remotedir}));
  	}
 #-------------------------------------------------
  sub LocalNotInRemote
@@ -354,44 +328,54 @@ a reference to a list of strings interpreted as regular-expressios ("regex")
 matching to something in the local pathnames, you do not want to list, 
 default empty list [ ]
 
-=item (value) get_option (void)
-=item (1)  set_option (value)
-The functions are generated by AUTOLOAD for all options.
-The syntax is not case-sensitive and the character '_' is optional.
-
 =head2 methods
 
-=item (ref_hash_local_files, ref_hash_local_dirs) ReadLocalDir (void)
+=item (ref_hash_local_files, ref_hash_local_dirs) object->ReadLocalDir (void)
+=item (ref_hash_local_files, ref_hash_local_dirs) object->ReadLocalDir (path)
+=item (void) object->ReadLocalDir (path)
 Returns two hashreferences first  the local-files, second the local-directorys
 found in the directory given by the MirrorDir-object,
-uses the attribute "localdir". 
-The values are in the keys.
+(uses the attribute "localdir") or given directly as parameter.
+The values are in the keys. You can also call the functions 
+ (ref_hash_local_dirs) object->GetLocalDirs()
+ (ref_hash_local_files) object->GetLocalFiles()
+in order to receive the results.
 
-=item (ref_hash_remotefiles, ref_hash_remote_dirs) ReadRemoteDir (void)
+=item (ref_hash_remote_files, ref_hash_remote_dirs) object->ReadRemoteDir (void)
+=item (ref_hash_remote_files, ref_hash_remote_dirs) object->ReadRemoteDir(path)
+=item (void) object->ReadRemoteDir (path)
 Returns two hashreferences first the remote-files, second the remote-directorys
 found in the directory given by the MirrorDir-object,
-uses the attribute "remotedir". 
-The values are in the keys.
+(uses the attribute "remotedir") or given directly as parameter. 
+The values are in the keys. You can also call the functions
+ (ref_hash_remote_files) object->GetRemoteFiles()
+ (ref_hash_remote_dirs) object->GetRemoteDirs()
+in order to receive the results.
 
-=item (1) Connect (void)
+=item (1) object->Connect (void)
 Makes the connection to the ftp-server.
 Uses the attributes "ftpserver", "usr" and "pass" given by the MirrorDir-object.
 
-=item (1) Quit (void)
+=item (1) object->Quit (void)
 Closes the connection with the ftp-server.
 
-=item (ref_hash_local_paths, ref_hash_remote_paths) LocalNotInRemote (ref_list_new_paths)
+=item (ref_hash_local_paths, ref_hash_remote_paths) object->LocalNotInRemote (ref_list_new_paths)
 Takes two hashreferences, given by the functions ReadLocalDir(); and ReadRemoteDir();
 to compare with each other. Returns a reference of a list with files or directorys found in 
 the local directory but not in the remote location. Uses the attribute "localdir" and 
 "remotedir" given by the MirrorDir-object.
 
-=item (ref_hash_local_paths, ref_hash_remote_paths) RemoteNotInLocal (ref_list_deleted_paths)
+=item (ref_hash_local_paths, ref_hash_remote_paths) object->RemoteNotInLocal (ref_list_deleted_paths)
 Takes two hashreferences, given by the functions ReadLocalDir(); and ReadRemoteDir();
 to compare with each other. Returns a reference of a list with files or directorys found in 
 the remote location but not in the local directory. Uses of the attribure "localdir" and 
 "remotedir" given by the MirrorDir-object.
 
+=item (value) object->get_option (void)
+=item (1)  set_object->option (value)
+The functions are generated by AUTOLOAD for all options.
+The syntax is not case-sensitive and the character '_' is optional.
+
 =head2 EXPORT
 
 None by default.
